package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.commandLog.domain.CommandLogQuery;
import com.ruoyi.bst.commandLog.domain.CommandLogVO;
import com.ruoyi.bst.commandLog.service.CommandLogService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 命令日志Controller
 *
 * @author ruoyi
 * @date 2025-04-03
 */
@RestController
@RequestMapping("/bst/commandLog")
public class CommandLogController extends BaseController
{
    @Autowired
    private CommandLogService commandLogService;

    /**
     * 查询命令日志列表
     */
    @PreAuthorize("@ss.hasPermi('bst:commandLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(CommandLogQuery query)
    {
        startPage();
        startOrderBy();
        List<CommandLogVO> list = commandLogService.selectCommandLogList(query);
        return getDataTable(list);
    }

    /**
     * 导出命令日志列表
     */
    @PreAuthorize("@ss.hasPermi('bst:commandLog:export')")
    @Log(title = "命令日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CommandLogQuery query)
    {
        List<CommandLogVO> list = commandLogService.selectCommandLogList(query);
        ExcelUtil<CommandLogVO> util = new ExcelUtil<CommandLogVO>(CommandLogVO.class);
        util.exportExcel(response, list, "命令日志数据");
    }

    /**
     * 获取命令日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:commandLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(commandLogService.selectCommandLogById(id));
    }

}
